@@ -9,8 +9,9 @@ from dagster import (
     executor,
 )
 from dagster._core.definitions.executor_definition import multiple_process_executor_requirements
+from dagster._core.definitions.metadata import MetadataValue
 from dagster._core.errors import DagsterUnmetExecutorRequirementsError
-from dagster._core.events import DagsterEvent, EngineEventData, MetadataEntry
+from dagster._core.events import DagsterEvent, EngineEventData
 from dagster._core.execution.retries import RetryMode, get_retries_config
 from dagster._core.execution.tags import get_tag_concurrency_limits_config
 from dagster._core.executor.base import Executor
@@ -21,7 +22,6 @@ from dagster._core.executor.step_delegating import (
     StepHandler,
     StepHandlerContext,
 )
-from dagster._utils import frozentags
 from dagster._utils.merger import merge_dicts
 
 from dagster_k8s.launcher import K8sRunLauncher
@@ -59,8 +59,7 @@ _K8S_EXECUTOR_CONFIG_SCHEMA = merge_dicts(
     requirements=multiple_process_executor_requirements(),
 )
 def k8s_job_executor(init_context: InitExecutorContext) -> Executor:
-    """
-    Executor which launches steps as Kubernetes Jobs.
+    """Executor which launches steps as Kubernetes Jobs.
 
     To use the `k8s_job_executor`, set it as the `executor_def` when defining a job:
 
@@ -189,7 +188,7 @@ class K8sStepHandler(StepHandler):
         context = context.merge(self._executor_container_context)
 
         user_defined_k8s_config = get_user_defined_k8s_config(
-            frozentags(step_handler_context.step_tags[step_key])
+            step_handler_context.step_tags[step_key]
         )
         return context.merge(K8sContainerContext(run_k8s_config=user_defined_k8s_config.to_dict()))
 
@@ -258,9 +257,9 @@ class K8sStepHandler(StepHandler):
         yield DagsterEvent.step_worker_starting(
             step_handler_context.get_step_context(step_key),
             message=f'Executing step "{step_key}" in Kubernetes job {job_name}.',
-            metadata_entries=[
-                MetadataEntry("Kubernetes Job name", value=job_name),
-            ],
+            metadata={
+                "Kubernetes Job name": MetadataValue.text(job_name),
+            },
         )
 
         self._api_client.batch_api.create_namespaced_job(
