@@ -20,7 +20,6 @@ from dagster._config import Permissive, Shape, validate_config
 from dagster._core.errors import DagsterInvalidConfigError
 from dagster._core.utils import parse_env_var
 from dagster._serdes import whitelist_for_serdes
-from dagster._utils import frozentags
 from dagster._utils.merger import merge_dicts
 
 from .models import k8s_model_from_dict, k8s_snake_case_dict
@@ -149,8 +148,8 @@ class UserDefinedDagsterK8sConfig(
         )
 
 
-def get_k8s_resource_requirements(tags):
-    check.inst_param(tags, "tags", frozentags)
+def get_k8s_resource_requirements(tags: Mapping[str, str]):
+    check.mapping_param(tags, "tags", key_type=str, value_type=str)
     check.invariant(K8S_RESOURCE_REQUIREMENTS_KEY in tags)
 
     resource_requirements = json.loads(tags[K8S_RESOURCE_REQUIREMENTS_KEY])
@@ -158,7 +157,7 @@ def get_k8s_resource_requirements(tags):
 
     if not result.success:
         raise DagsterInvalidConfigError(
-            "Error in tags for {}".format(K8S_RESOURCE_REQUIREMENTS_KEY),
+            f"Error in tags for {K8S_RESOURCE_REQUIREMENTS_KEY}",
             result.errors,
             result,
         )
@@ -166,8 +165,8 @@ def get_k8s_resource_requirements(tags):
     return result.value
 
 
-def get_user_defined_k8s_config(tags):
-    check.inst_param(tags, "tags", frozentags)
+def get_user_defined_k8s_config(tags: Mapping[str, str]):
+    check.mapping_param(tags, "tags", key_type=str, value_type=str)
 
     if not any(key in tags for key in [K8S_RESOURCE_REQUIREMENTS_KEY, USER_DEFINED_K8S_CONFIG_KEY]):
         return UserDefinedDagsterK8sConfig()
@@ -180,14 +179,14 @@ def get_user_defined_k8s_config(tags):
 
         if not result.success:
             raise DagsterInvalidConfigError(
-                "Error in tags for {}".format(USER_DEFINED_K8S_CONFIG_KEY),
+                f"Error in tags for {USER_DEFINED_K8S_CONFIG_KEY}",
                 result.errors,
                 result,
             )
 
         user_defined_k8s_config = result.value
 
-    container_config = user_defined_k8s_config.get("container_config", {})
+    container_config = user_defined_k8s_config.get("container_config", {})  # type: ignore
 
     # Backcompat for resource requirements key
     if K8S_RESOURCE_REQUIREMENTS_KEY in tags:
@@ -198,17 +197,17 @@ def get_user_defined_k8s_config(tags):
 
     return UserDefinedDagsterK8sConfig(
         container_config=container_config,
-        pod_template_spec_metadata=user_defined_k8s_config.get("pod_template_spec_metadata"),
-        pod_spec_config=user_defined_k8s_config.get("pod_spec_config"),
-        job_config=user_defined_k8s_config.get("job_config"),
-        job_metadata=user_defined_k8s_config.get("job_metadata"),
-        job_spec_config=user_defined_k8s_config.get("job_spec_config"),
+        pod_template_spec_metadata=user_defined_k8s_config.get("pod_template_spec_metadata"),  # type: ignore
+        pod_spec_config=user_defined_k8s_config.get("pod_spec_config"),  # type: ignore
+        job_config=user_defined_k8s_config.get("job_config"),  # type: ignore
+        job_metadata=user_defined_k8s_config.get("job_metadata"),  # type: ignore
+        job_spec_config=user_defined_k8s_config.get("job_spec_config"),  # type: ignore
     )
 
 
 def get_job_name_from_run_id(run_id, resume_attempt_number=None):
-    return "dagster-run-{}".format(run_id) + (
-        "" if not resume_attempt_number else "-{}".format(resume_attempt_number)
+    return f"dagster-run-{run_id}" + (
+        "" if not resume_attempt_number else f"-{resume_attempt_number}"
     )
 
 
@@ -390,6 +389,7 @@ class DagsterK8sJobConfig(
                     is_required=False,
                     description="Raw Kubernetes configuration for launched runs.",
                 ),
+                "job_namespace": Field(StringSource, is_required=False, default_value="default"),
             },
         )
 
@@ -631,7 +631,7 @@ def construct_dagster_k8s_job(
     labels: Optional[Mapping[str, str]] = None,
     env_vars: Optional[Sequence[Mapping[str, Any]]] = None,
 ) -> kubernetes.client.V1Job:
-    """Constructs a Kubernetes Job object
+    """Constructs a Kubernetes Job object.
 
     Args:
         job_config: Job configuration to use for constructing the Kubernetes
